retro_core_options_v2

Struct retro_core_options_v2 

#[repr(C)]
pub struct retro_core_options_v2 { pub categories: *mut retro_core_option_v2_category, pub definitions: *mut retro_core_option_v2_definition, }

Fields

categories: *mut retro_core_option_v2_category

Array of retro_core_option_v2_category structs, terminated by NULL

If NULL, all entries in definitions array will have no category and will be shown at the top level of the frontend core option interface Will be ignored if frontend does not have core option category support

definitions: *mut retro_core_option_v2_definition

Array of retro_core_option_v2_definition structs, terminated by NULL